==> login-1.0.15.zip: src/view.php <==
<?php
    function emailCheck($inputData) { // Upgraded
        $result = [];
        try {
            $db = $inputData['db']['dbLogin'];
            $stmt = $db->prepare("SELECT pk_user_id, fk_user_status_id FROM user_login WHERE UPPER(user_email) = UPPER(:email)");
            $stmt->bindValue(':email', $inputData['email']);
            $stmt->execute();
            $row = $stmt->fetch(PDO::FETCH_ASSOC);
            if ($row) {
                $result['UserExists'] = $row['pk_user_id'];
                $result['userStatus'] = $row['fk_user_status_id'];
            } else {
                $result['UserExists'] = 'failed';
                $result['email'] = $inputData['email'];
            }
        } catch (PDOException $e) {
            if (isset($inputData['debug']) && $inputData['debug'] === $inputData['debugMode']) {
                // Output the error message
                $result['message'] = $e->getMessage();
                $result['status'] = 'failed';
            }else{
                $result['status'] = 'error';
                $result['message'] = 'Database error:';
            }
        }
        return $result;
    }
    function userType($inputData){
        $userID = $_SESSION['id'];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("select fk_role_id from `user_permissions` where fk_user_id = :userId and fk_system_id = :systemId");
        $stmt->bindParam(':userId', $userID);
        $stmt->bindParam('systemId',$inputData['systemId']);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row) { 
            $roleValue = $row !== false ? $row['fk_role_id'] : 0;
        }else{
            $roleValue = 0;
        }
        $_SESSION['roleValue'] = $roleValue;
        return;        
    }
    function emailCheckWithID($inputData){
        $result = [];
        $userID =  $_SESSION['id'];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("Select fk_user_status_id from user_login where pk_user_id = :userId");
        $stmt->bindParam(':userId', $userID);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row) { 
            $result['userStatus'] = $row !== false ? $row['fk_user_status_id'] : null;
            $result['status']    = 'success';

        }else{
            $result['UserExists']   = 'failed';
            $result['status']       = 'ignor';

        //    $result['emailCheck1']  = $stmt;
        //    $result['emailCheck2']  = $stmt->errorInfo();
        }        
        return  $result;
    }
    function getPassword($inputData){
        $result = [];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("SELECT user_password FROM user_login WHERE UPPER(user_email) = UPPER(:email)");
        $stmt->bindParam(':email', $inputData['email']);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row && isset($row['user_password'])) {
            return $row['user_password']; // Just return password directly if found
        }
        $result['email'] = $inputData['email'];
        $result['user_password'] = 'failed';
        return $result;
    }
    function getEmailAddress($inputData){
        $result = [];
        $userID =  $_SESSION['id'];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("select user_email from user_login where pk_user_id = :userId");
        $stmt->bindParam(':userId', $userID);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row) { 
            $result['user_email'] = $row !== false ? $row['user_email'] : null;
            $result['status']    = 'success';
        }else{
            $result['status']    = 'failed';
        //    $result['getPassword1']     = $stmt;
        //    $result['getPassword2']     = $stmt->errorInfo();
        //    $result['id'] =  $_SESSION['id'];
        }
        return  $result;
    }
    function simpleEmailCheck($inputData){
        $result = [];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("Select pk_user_id from user_login where upper(user_email) = upper(:email)");
        $stmt->bindParam(':email', $inputData['email']);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row) { 
            $result['userId'] = $row !== false ? $row['pk_user_id'] : 0;
            $result['status']    = 'success';
        }else{
            $result['status']    = 'failed';
            $result['msg']       = 'Email not found';
        }        
        return  $result;
    }
    function checkStatusOfUser($inputData){
        $result = [];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("select fk_user_status_id from user_login where pk_user_id = :userId");
        $stmt->bindParam(':userId', $inputData['userId']);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row) { 
            $result['userStatus'] = $row !== false ? $row['fk_user_status_id'] : 0;
            $result['status']    = 'success';
        }else{
            $result['status']    = 'failed';
            $result['msg']       = 'User not found';
        }
        return  $result;
    }
    function lookupUser($inputData){
        $result = [];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("SELECT pk_user_id, user_email, f_name, l_name, phone_number FROM user_login WHERE pk_user_id = :userId");
        $stmt->bindParam(':userId', $inputData['lookupUserId']);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row) { 
            $lookup['status']       = 'success';
            $lookup['email']        = $row['user_email'];
            $lookup['userId']       = $row['pk_user_id'];
            $lookup['fName']        = $row['f_name'];
            $lookup['lName']        = $row['l_name'];
            $lookup['phoneNumber']  = $row['phone_number'];
        }else{
            $lookup['status']    = 'failed';
            $lookup['msg']       = 'User not found';
        }
        return  $result = [ 'lookup' => $lookup];
    }
    function checkIfTenantInSystem($inputData){
        $result = [];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("SELECT pk_system_id FROM user_system WHERE fk_tenant_id = :tenantId");
        $stmt->bindParam(':tenantId', $inputData['tenantId']);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row) { 
            $result['status']    = 'found';
        }else{
            $result['status']    = 'notfound';
        }
        return  $result;
    }
    function lookupRoleByName($inputData){
        $result = [];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("SELECT pk_role_id FROM user_role WHERE role_name = :roleName");
        $stmt->bindParam(':roleName', $inputData['requestedRole']);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row) { 
            $result['status']    = 'success';
            $result['requestedRoleId']    = $row['pk_role_id'];
        }else{
            $result['status']    = 'failed';
            $result['msg']       = 'Role not found';
        }
        return  $result;
    }
    function getSysyemIdFromTenantId($inputData){
        $result = [];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("SELECT pk_system_id FROM user_system WHERE fk_tenant_id = :tenantId");
        $stmt->bindParam(':tenantId', $inputData['tenantId']);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row) { 
            $result['status']    = 'success';
            $result['systemId']  = $row['pk_system_id'];
        }else{
            $result['status']    = 'failed';
            $result['msg']       = 'System not found';
        }
        return  $result;
    }
    function viewRoles($inputData){
        $result = [];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("SELECT pk_role_id, role_name FROM user_role where scope != 'Platform' and pk_role_id > :roleId");
        $stmt->bindParam(':roleId', $inputData['roleId']);
        $stmt->execute();
        $row = $stmt->fetchAll(PDO::FETCH_ASSOC);
        if ($row) { 
            foreach($row as $key => $value){
                $result[$key]['roleId']   = $value['pk_role_id'];
                $result[$key]['roleName'] = $value['role_name'];
            }
            $result['status']    = 'success';
        }else{
            $result['status']    = 'failed';
            $result['msg']       = 'Role not found';
        }
        return  $result;
    }
?>

==> login-1.0.16.zip: src/view.php <==
<?php
    function emailCheck($inputData) { // Upgraded
        $result = [];
        try {
            $db = $inputData['db']['dbLogin'];
            $stmt = $db->prepare("SELECT pk_user_id, fk_user_status_id FROM user_login WHERE UPPER(user_email) = UPPER(:email)");
            $stmt->bindValue(':email', $inputData['email']);
            $stmt->execute();
            $row = $stmt->fetch(PDO::FETCH_ASSOC);
            if ($row) {
                $result['UserExists'] = $row['pk_user_id'];
                $result['userStatus'] = $row['fk_user_status_id'];
            } else {
                $result['UserExists'] = 'failed';
                $result['email'] = $inputData['email'];
            }
        } catch (PDOException $e) {
            if (isset($inputData['debug']) && $inputData['debug'] === $inputData['debugMode']) {
                // Output the error message
                $result['message'] = $e->getMessage();
                $result['status'] = 'failed';
            }else{
                $result['status'] = 'error';
                $result['message'] = 'Database error:';
            }
        }
        return $result;
    }
    function userType($inputData){
        $userID = $_SESSION['id'];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("select fk_role_id from `user_permissions` where fk_user_id = :userId and fk_system_id = :systemId");
        $stmt->bindParam(':userId', $userID);
        $stmt->bindParam('systemId',$inputData['systemId']);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row) { 
            $roleValue = $row !== false ? $row['fk_role_id'] : 0;
        }else{
            $roleValue = 0;
        }
        $_SESSION['roleValue'] = $roleValue;
        return;        
    }
    function emailCheckWithID($inputData){
        $result = [];
        $userID =  $_SESSION['id'];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("Select fk_user_status_id from user_login where pk_user_id = :userId");
        $stmt->bindParam(':userId', $userID);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row) { 
            $result['userStatus'] = $row !== false ? $row['fk_user_status_id'] : null;
            $result['status']    = 'success';

        }else{
            $result['UserExists']   = 'failed';
            $result['status']       = 'ignor';

        //    $result['emailCheck1']  = $stmt;
        //    $result['emailCheck2']  = $stmt->errorInfo();
        }        
        return  $result;
    }
    function getPassword($inputData){
        $result = [];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("SELECT user_password FROM user_login WHERE UPPER(user_email) = UPPER(:email)");
        $stmt->bindParam(':email', $inputData['email']);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row && isset($row['user_password'])) {
            return $row['user_password']; // Just return password directly if found
        }
        $result['email'] = $inputData['email'];
        $result['user_password'] = 'failed';
        return $result;
    }
    function getEmailAddress($inputData){
        $result = [];
        $userID =  $_SESSION['id'];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("select user_email from user_login where pk_user_id = :userId");
        $stmt->bindParam(':userId', $userID);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row) { 
            $result['user_email'] = $row !== false ? $row['user_email'] : null;
            $result['status']    = 'success';
        }else{
            $result['status']    = 'failed';
        //    $result['getPassword1']     = $stmt;
        //    $result['getPassword2']     = $stmt->errorInfo();
        //    $result['id'] =  $_SESSION['id'];
        }
        return  $result;
    }
    function simpleEmailCheck($inputData){
        $result = [];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("Select pk_user_id from user_login where upper(user_email) = upper(:email)");
        $stmt->bindParam(':email', $inputData['email']);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row) { 
            $result['userId'] = $row !== false ? $row['pk_user_id'] : 0;
            $result['status']    = 'success';
        }else{
            $result['status']    = 'failed';
            $result['msg']       = 'Email not found';
        }        
        return  $result;
    }
    function checkStatusOfUser($inputData){
        $result = [];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("select fk_user_status_id from user_login where pk_user_id = :userId");
        $stmt->bindParam(':userId', $inputData['userId']);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row) { 
            $result['userStatus'] = $row !== false ? $row['fk_user_status_id'] : 0;
            $result['status']    = 'success';
        }else{
            $result['status']    = 'failed';
            $result['msg']       = 'User not found';
        }
        return  $result;
    }
    function lookupUser($inputData){
        $result = [];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("SELECT pk_user_id, user_email, f_name, l_name, phone_number FROM user_login WHERE pk_user_id = :userId");
        $stmt->bindParam(':userId', $inputData['lookupUserId']);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row) { 
            $lookup['status']       = 'success';
            $lookup['email']        = $row['user_email'];
            $lookup['userId']       = $row['pk_user_id'];
            $lookup['fName']        = $row['f_name'];
            $lookup['lName']        = $row['l_name'];
            $lookup['phoneNumber']  = $row['phone_number'];
        }else{
            $lookup['status']    = 'failed';
            $lookup['msg']       = 'User not found';
        }
        return  $result = [ 'lookup' => $lookup];
    }
    function checkIfTenantInSystem($inputData){
        $result = [];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("SELECT pk_system_id FROM user_system WHERE fk_tenant_id = :tenantId");
        $stmt->bindParam(':tenantId', $inputData['tenantId']);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row) { 
            $result['status']    = 'found';
        }else{
            $result['status']    = 'notfound';
        }
        return  $result;
    }
    function lookupRoleByName($inputData){
        $result = [];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("SELECT pk_role_id FROM user_role WHERE role_name = :roleName");
        $stmt->bindParam(':roleName', $inputData['requestedRole']);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row) { 
            $result['status']    = 'success';
            $result['requestedRoleId']    = $row['pk_role_id'];
        }else{
            $result['status']    = 'failed';
            $result['msg']       = 'Role not found';
        }
        return  $result;
    }
    function getSysyemIdFromTenantId($inputData){
        $result = [];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("SELECT pk_system_id FROM user_system WHERE fk_tenant_id = :tenantId");
        $stmt->bindParam(':tenantId', $inputData['tenantId']);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row) { 
            $result['status']    = 'success';
            $result['systemId']  = $row['pk_system_id'];
        }else{
            $result['status']    = 'failed';
            $result['msg']       = 'System not found';
        }
        return  $result;
    }
    function viewRoles($inputData){
        $result = [];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("SELECT pk_role_id, role_name FROM user_role where scope != 'Platform' and pk_role_id > :roleId");
        $stmt->bindParam(':roleId', $inputData['roleId']);
        $stmt->execute();
        $row = $stmt->fetchAll(PDO::FETCH_ASSOC);
        if ($row) { 
            foreach($row as $key => $value){
                $result[$key]['roleId']   = $value['pk_role_id'];
                $result[$key]['roleName'] = $value['role_name'];
            }
            $result['status']    = 'success';
        }else{
            $result['status']    = 'failed';
            $result['msg']       = 'Role not found';
        }
        return  $result;
    }
    function getSysyemIdFromDomain($inputData){
        $result = [];
        $db = $inputData['db']['dbLogin'];
        $stmt = $db->prepare("SELECT pk_system_id FROM user_system WHERE tenant_base_url = :tenantBaseUrl");
        $stmt->bindParam(':tenantBaseUrl', $_SERVER['HTTP_HOST']);
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($row) { 
            $result['status']    = 'success';
            $result['systemId']  = $row['pk_system_id'];
        }else{
            $result['status']    = 'failed';
            $result['msg']       = 'System not found';
        }
        return  $result;
    }
?>
